import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import chronoMini from 'assets/icons/visu/action/chrono-mini.svg'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { UserChallengeUpdateFlag } from 'enum/userChallenge.enum'
import { Ecogesture, UserChallenge } from 'models'
import React, { Dispatch, useCallback } from 'react'
import { useDispatch } from 'react-redux'
import ChallengeService from 'services/challenge.service'
import { AppActionsTypes } from 'store'
import { updateUserChallengeList } from 'store/challenge/challenge.actions'
import './actionModal.scss'

interface ActionModalProps {
  open: boolean
  action: Ecogesture
  handleCloseClick: () => void
  userChallenge: UserChallenge
}

const ActionModal: React.FC<ActionModalProps> = ({
  open,
  action,
  handleCloseClick,
  userChallenge,
}: ActionModalProps) => {
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()
  const client = useClient()
  const { t } = useI18n()
  const launchAction = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    const updatedChallenge: UserChallenge =
      await challengeService.updateUserChallenge(
        userChallenge,
        UserChallengeUpdateFlag.ACTION_START,
        undefined,
        undefined,
        action
      )
    dispatch(updateUserChallengeList(updatedChallenge))
  }, [action, client, dispatch, userChallenge])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id={'accessibility-title'}>
        {t('action_modal.accessibility.window_title')}
      </div>
      <div className="action-modal">
        <Icon icon={chronoMini} size={75} />
        <div className="action-title text-16-normal">
          {t('action.duration', {
            // eslint-disable-next-line camelcase
            smart_count: action.actionDuration,
          })}
        </div>
        <div className="action-text text-16-normal">{action.longName}</div>
        <div className="buttons">
          <Button
            aria-label={t('action_modal.accessibility.button_accept')}
            classes={{
              root: 'btn-secondary-negative',
              label: 'text-16-normal',
            }}
            onClick={launchAction}
          >
            {t('action_modal.accept')}
          </Button>
          <Button
            aria-label={t('action_modal.accessibility.button_refuse')}
            classes={{
              root: 'btn-secondary-negative',
              label: 'text-16-normal',
            }}
            onClick={handleCloseClick}
          >
            {t('action_modal.refuse')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default ActionModal
