import { mount } from 'enzyme'
import { DateTime } from 'luxon'
import React from 'react'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { dataLoadArray } from '../../../tests/__mocks__/chartData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import ElecHalfHourChart from './ElecHalfHourChart'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockcompareStepDate = jest.fn()
jest.mock('services/dateChart.service', () => {
  return jest.fn(() => {
    return {
      compareStepDate: mockcompareStepDate,
    }
  })
})
const mockStore = configureStore([])
const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

describe('ElecHalfHourChart component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    mockUseSelector.mockReturnValue(
      DateTime.fromISO('2021-07-01T00:00:00.000Z', {
        zone: 'utc',
      })
    )
    const wrapper = mount(
      <Provider store={store}>
        <ElecHalfHourChart dataLoad={dataLoadArray} isWeekend={true} />
      </Provider>
    ).getElement()
    expect(wrapper).toMatchSnapshot()
  })
  it('should render week data', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    mockUseSelector.mockReturnValue(
      DateTime.fromISO('2021-07-01T00:00:00.000Z', {
        zone: 'utc',
      })
    )
    const wrapper = mount(
      <Provider store={store}>
        <ElecHalfHourChart dataLoad={dataLoadArray} isWeekend={false} />
      </Provider>
    )
    expect(wrapper.find('.week')).toBeTruthy()
  })
})
