import CardActionArea, {
  CardActionAreaProps,
} from '@material-ui/core/CardActionArea'
import CardContent from '@material-ui/core/CardContent'
import { withStyles } from '@material-ui/core/styles'
import { FluidType } from 'enum/fluid.enum'
import React, { ReactNode } from 'react'

const CardBase = withStyles({
  root: {
    background: 'var(--greyLinearGradientBackground)',
    boxSizing: 'border-box',
    boxShadow: '0px 4px 8px rgba(0, 0, 0, 0.75)',
    borderRadius: '4px',
    margin: '10px 0px 10px 0px',
  },
})(CardActionArea) as React.FC<StyledCardProps>

const CardElec = withStyles({
  root: {
    border: '1px solid var(--elecColor40)',
  },
})(CardBase) as React.FC<StyledCardProps>

const CardWater = withStyles({
  root: {
    border: '1px solid var(--waterColor40)',
  },
})(CardBase) as React.FC<StyledCardProps>

const CardGas = withStyles({
  root: {
    border: '1px solid var(--gasColor40)',
  },
})(CardBase) as React.FC<StyledCardProps>

const CardMulti = withStyles({
  root: {
    border: '1px solid var( --greyDark)',
  },
})(CardBase) as React.FC<StyledCardProps>

const CardContentBase = withStyles({
  root: {
    color: 'white',
  },
})(CardContent) as React.FC<StyledCardProps>

interface StyledCardProps extends CardActionAreaProps {
  fluidType?: FluidType
}

const GenerateContentCard = (
  fluidType: FluidType,
  children: ReactNode
): React.ReactFragment => {
  return <CardContentBase>{children}</CardContentBase>
}

const StyledCard = ({ fluidType, ...props }: StyledCardProps) => {
  switch (fluidType) {
    case FluidType.ELECTRICITY:
      return (
        <CardElec {...props}>
          {GenerateContentCard(fluidType, props.children)}
        </CardElec>
      )
    case FluidType.WATER:
      return (
        <CardWater {...props}>
          {GenerateContentCard(fluidType, props.children)}
        </CardWater>
      )
    case FluidType.GAS:
      return (
        <CardGas {...props}>
          {GenerateContentCard(fluidType, props.children)}
        </CardGas>
      )
    case FluidType.MULTIFLUID:
      return (
        <CardMulti {...props}>
          {GenerateContentCard(fluidType, props.children)}
        </CardMulti>
      )
    default:
      return (
        <CardBase {...props}>
          <CardContentBase>{props.children}</CardContentBase>
        </CardBase>
      )
  }
}

export default StyledCard
