import { FluidType } from 'enum/fluid.enum'
import { FluidConnection, FluidStatus } from 'models'
import React, { Dispatch, useCallback } from 'react'
import { useDispatch } from 'react-redux'
import { AppActionsTypes } from 'store'
import { updatedFluidConnection } from 'store/global/global.actions'
import EpglInit from './EPGLConnect/EpglInit'
import GrdfInit from './GRDFConnect/GrdfInit'
import SgeInit from './SGEConnect/SgeInit'
import './connection.scss'
interface ConnectionProps {
  fluidStatus: FluidStatus
}

const Connection: React.FC<ConnectionProps> = ({
  fluidStatus,
}: ConnectionProps) => {
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()

  const handleSuccess = useCallback(async () => {
    const updatedConnection: FluidConnection = {
      ...fluidStatus.connection,
      shouldLaunchKonnector: true,
    }
    dispatch(updatedFluidConnection(fluidStatus.fluidType, updatedConnection))
  }, [dispatch, fluidStatus.fluidType, fluidStatus.connection])
  return (
    <div className="konnector-form">
      {fluidStatus.fluidType === FluidType.ELECTRICITY && (
        <SgeInit fluidStatus={fluidStatus} />
      )}
      {fluidStatus.fluidType === FluidType.WATER && (
        <EpglInit fluidStatus={fluidStatus} />
      )}
      {fluidStatus.fluidType === FluidType.GAS && (
        <GrdfInit fluidStatus={fluidStatus} onSuccess={handleSuccess} />
      )}
    </div>
  )
}

export default Connection
