import EpglConnectModal from 'components/Connection/PartnerConnectModal/EpglConnectModal'
import { FluidStatus } from 'models'
import React, { Dispatch, useCallback, useState } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { AppActionsTypes, AppStore } from 'store'
import { openConnectionModal } from 'store/modal/modal.slice'
import '../connection.scss'
import EpglBill from './EpglBill'
import EpglForm from './EpglForm'

interface EpglInitProps {
  fluidStatus: FluidStatus
}

const EpglInit: React.FC<EpglInitProps> = ({ fluidStatus }: EpglInitProps) => {
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()
  const {
    modal: { isConnectionModalOpen },
  } = useSelector((state: AppStore) => state.ecolyo)
  const siteLink: string = fluidStatus.connection.konnectorConfig.siteLink

  const [showForm, setShowForm] = useState(false)
  const [hasCreatedAccount, setHasCreatedAccount] = useState(false)

  const goToPartnerSite = useCallback(() => {
    window.open(siteLink, '_blank')
  }, [siteLink])

  return (
    <>
      {!showForm ? (
        <EpglBill fluidStatus={fluidStatus} />
      ) : (
        <EpglForm
          fluidStatus={fluidStatus}
          hasCreatedAccount={hasCreatedAccount}
        />
      )}
      <EpglConnectModal
        open={isConnectionModalOpen}
        handleCloseClick={() => dispatch(openConnectionModal(false))}
        setShowForm={setShowForm}
        goToPartnerSite={goToPartnerSite}
        setHasCreatedAccount={setHasCreatedAccount}
      />
    </>
  )
}

export default EpglInit
