import Button from '@material-ui/core/Button'
import GasBillIcon from 'assets/icons/visu/onboarding/gas_bill.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { FluidStatus } from 'models'
import React, { Dispatch } from 'react'
import { useDispatch } from 'react-redux'
import { AppActionsTypes } from 'store'
import { setShowOfflineData } from 'store/chart/chart.slice'
import { openConnectionModal } from 'store/modal/modal.slice'
import { decoreText } from 'utils/decoreText'
import '../connection.scss'

const GrdfBill = ({ fluidStatus }: { fluidStatus: FluidStatus }) => {
  const { t } = useI18n()
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()

  return (
    <div className="connection-form">
      <p className={'connection-form-title grdfgrandlyon text-20-bold'}>
        {t('auth.grdfgrandlyon.no_account.title')}
      </p>
      <StyledIcon icon={GasBillIcon} size={180} />
      <p className={'connection-form-subtitle grdfgrandlyon text-16-regular'}>
        {decoreText(t('auth.grdfgrandlyon.bill'))}
      </p>

      <div className="connection-form-button">
        <Button
          aria-label={t('auth.grdfgrandlyon.accessibility.connect')}
          onClick={() => dispatch(openConnectionModal(true))}
          classes={{
            root: 'btn-highlight',
            label: 'text-16-bold',
          }}
        >
          {t('auth.grdfgrandlyon.connect')}
        </Button>
        {fluidStatus.firstDataDate && (
          <Button
            classes={{
              root: 'btn-secondary',
              label: 'text-16-bold',
            }}
            onClick={() => dispatch(setShowOfflineData(true))}
          >
            {t('auth.button_showOfflineData')}
          </Button>
        )}
      </div>
    </div>
  )
}

export default GrdfBill
