import FeedbackModal from 'components/Feedback/FeedbackModal'
import { ScreenType } from 'enum/screen.enum'
import React, { Dispatch, useCallback, useEffect } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { AppActionsTypes, AppStore } from 'store'
import { changeScreenType } from 'store/global/global.actions'
import { openFeedbackModal } from 'store/modal/modal.slice'
import './content.scss'
interface ContentProps {
  children?: React.ReactNode
  height?: number
  background?: string
}

const Content: React.FC<ContentProps> = ({
  children,
  height = 0,
  background = 'inherit',
}: ContentProps) => {
  const dispatch = useDispatch<Dispatch<AppActionsTypes>>()
  const {
    global: { screenType },
    modal: { isFeedbacksOpen },
  } = useSelector((state: AppStore) => state.ecolyo)

  const cozyBarHeight = 48
  const cozyNavHeight = 56

  const handleFeedbackModalClose = useCallback(() => {
    dispatch(openFeedbackModal(false))
  }, [dispatch])

  // Set listeners for scroll
  useEffect(() => {
    window.scrollTo(0, 0)
  }, [])

  useEffect(() => {
    function handleResize() {
      if (innerWidth <= 768) {
        dispatch(changeScreenType(ScreenType.MOBILE))
      } else if (innerWidth <= 1024) {
        dispatch(changeScreenType(ScreenType.TABLET))
      } else {
        dispatch(changeScreenType(ScreenType.DESKTOP))
      }
    }
    handleResize()
    window.addEventListener('resize', handleResize)
    return () => {
      window.removeEventListener('resize', handleResize)
    }
  }, [dispatch])

  return (
    <>
      <FeedbackModal
        open={isFeedbacksOpen}
        handleCloseClick={handleFeedbackModalClose}
      />
      <div
        className={'content-view'}
        style={{
          marginTop: height,
          paddingBottom: 0,
          minHeight:
            screenType !== ScreenType.DESKTOP
              ? `calc(100vh - ${height}px - ${cozyBarHeight}px - ${cozyNavHeight}px - env(safe-area-inset-top) - env(safe-area-inset-bottom) - env(safe-area-inset-bottom))`
              : `unset`,
          background: background,
        }}
      >
        {children}
      </div>
    </>
  )
}

export default Content
