import { Button, IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import './ecogestureInitModal.scss'
interface EcogestureInitModalProps {
  open: boolean
  handleCloseClick: () => void
  handleLaunchForm: () => void
}
const EcogestureInitModal: React.FC<EcogestureInitModalProps> = ({
  open,
  handleCloseClick,
  handleLaunchForm,
}: EcogestureInitModalProps) => {
  const { t } = useI18n()
  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id={'accessibility-title'}>
        {t('feedback.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="eg-init-modal">
        <div className="title text-20-bold">
          {t('ecogesture.initModal.title')}
        </div>
        <div className="text-16-normal text">
          {t('ecogesture.initModal.text1')}
        </div>
        <div className="text-16-normal text">
          {t('ecogesture.initModal.text2')}
        </div>
        <div className="buttons-container">
          <Button
            aria-label={t('ecogesture.initModal.btn1')}
            onClick={handleCloseClick}
            className="btn1"
            classes={{
              root: 'btn-secondary-negative',
              label: 'text-16-bold',
            }}
          >
            {t('ecogesture.initModal.btn1')}
          </Button>
          <Button
            aria-label={t('ecogesture.initModal.btn2')}
            onClick={handleLaunchForm}
            classes={{
              root: 'btn-profile-next rounded',
              label: 'text-16-bold',
            }}
          >
            {t('ecogesture.initModal.btn2')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default EcogestureInitModal
