import { Button } from '@material-ui/core'
import ExportStartModal from 'components/Export/exportStartModal'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from '../../../tests/__mocks__/store'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockHandleClose = jest.fn()
const mockHandleDownloadClick = jest.fn()

describe('exportStartModal component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    store.clearActions()
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportStartModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleDownloadClick={mockHandleDownloadClick}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should close modal ', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportStartModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleDownloadClick={mockHandleDownloadClick}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockHandleClose).toHaveBeenCalledTimes(1)
  })
})
