import { useEffect, useState } from 'react'

export const useChartResize = (
  ref: React.RefObject<HTMLDivElement>,
  maxHeight = 300,
  maxWidth = 940,
  loading = false
) => {
  const [width, setWidth] = useState(0)
  const [height, setHeight] = useState(0)

  useEffect(() => {
    function handleResize() {
      if (!loading) {
        const chartContainerWidth = ref?.current?.offsetWidth ?? 400
        const chartContainerHeight = ref?.current?.offsetHeight ?? 200
        const width = Math.min(chartContainerWidth, maxWidth)
        const height = Math.min(chartContainerHeight, maxHeight)
        setWidth(width)
        setHeight(height)
      }
    }

    handleResize()
    window.addEventListener('resize', handleResize)
    return () => window.removeEventListener('resize', handleResize)
  }, [loading])

  return { width, height }
}
