import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { FluidType } from 'enum/fluid.enum'
import { DateTime } from 'luxon'
import { PerformanceIndicator } from 'models'
import React from 'react'
import { getPicto } from 'utils/picto'
import { formatNumberValues, getMonthName } from 'utils/utils'
import './fluidPerformanceIndicator.scss'

interface FluidPerformanceIndicatorProps {
  performanceIndicator: PerformanceIndicator
  fluidType: FluidType
  comparisonDate: DateTime
}

const FluidPerformanceIndicator: React.FC<FluidPerformanceIndicatorProps> = ({
  performanceIndicator,
  fluidType,
  comparisonDate,
}: FluidPerformanceIndicatorProps) => {
  const { t } = useI18n()
  const iconType = getPicto(fluidType)
  const displayedValue = performanceIndicator?.value
    ? formatNumberValues(performanceIndicator.value).toString()
    : ''
  const positive =
    performanceIndicator?.percentageVariation &&
    performanceIndicator?.percentageVariation > 0
  const percentSwitch = (percentage: number) => {
    if (positive) {
      return `+${formatNumberValues(percentage * 100)} %`
    } else {
      return `-${formatNumberValues(Math.abs(percentage) * 100)} %`
    }
  }

  return (
    <div className="fpi">
      <StyledIcon icon={iconType} size={50} />
      <div className="fpi-content">
        {!displayedValue && (
          <div className="fpi-content-no-data">
            <span>{t('performance_indicator.fpi.no_data')}</span>
          </div>
        )}
        {displayedValue && (
          <>
            <div className="fpi-value">
              <span className="fpi-load">{displayedValue}</span>
              <span className="fpi-unit">
                {t('FLUID.' + FluidType[fluidType] + '.UNIT')}
              </span>
            </div>
            {performanceIndicator?.percentageVariation === null && (
              <span className="fpi-no-comparison">
                {t('performance_indicator.fpi.no_comparison')}
              </span>
            )}
            {performanceIndicator?.percentageVariation !== null && (
              <div className={`fpi-comparison`}>
                <span
                  className={`percent ${positive ? 'positive' : 'negative'}`}
                >
                  {percentSwitch(performanceIndicator.percentageVariation)}
                </span>
                <span className="fpi-comparison-date">
                  {` / ${getMonthName(comparisonDate)} ${comparisonDate.year}`}
                </span>
              </div>
            )}
          </>
        )}
      </div>
    </div>
  )
}

export default FluidPerformanceIndicator
