import classNames from 'classnames'
import FormNavigation from 'components/FormGlobal/FormNavigation'
import FormProgress from 'components/FormGlobal/FormProgress'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { ProfileTypeStepForm } from 'enum/profileType.enum'
import {
  ProfileType,
  ProfileTypeAnswer,
  ProfileTypeAnswerChoices,
} from 'models/profileType.model'
import React, { useCallback, useEffect, useState } from 'react'

interface ProfileTypeFormSingleChoiceProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  profileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: (_profileType?: ProfileType) => void
  setPreviousStep: (_profileType: ProfileType) => void
  isProfileTypeComplete: boolean
}

const ProfileTypeFormSingleChoice: React.FC<
  ProfileTypeFormSingleChoiceProps
> = ({
  step,
  viewedStep,
  profileType,
  answerType,
  setNextStep,
  setPreviousStep,
  isProfileTypeComplete,
}: ProfileTypeFormSingleChoiceProps) => {
  const { t } = useI18n()
  const [answer, setAnswer] = useState<ProfileTypeAnswerChoices>('')

  const handlePrevious = useCallback(() => {
    setPreviousStep(profileType)
  }, [profileType, setPreviousStep])

  const handleNext = useCallback(() => {
    profileType[answerType.attribute] = answer
    setNextStep(profileType)
  }, [profileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    if (step < viewedStep || isProfileTypeComplete) {
      setAnswer(profileType[answerType.attribute])
    }
  }, [step, viewedStep, profileType, answerType, isProfileTypeComplete])

  return (
    <>
      <div className={'profile-form-container'}>
        <FormProgress step={step} formType={'profile'} />
        <div className={'profile-question-label'}>
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answerType.choices.map(
          (value: ProfileTypeAnswerChoices, index: number) => {
            return value || value === 0 ? (
              <label
                key={index}
                className={classNames({
                  ['radio_short']: answerType.choices.length < 5,
                  ['radio_long']: answerType.choices.length > 4,
                  ['answer-checked']: answer === value,
                })}
              >
                <input
                  type={'radio'}
                  value={value}
                  name={value.toString()}
                  onChange={() => setAnswer(value)}
                  checked={answer === value ? true : false}
                />
                {t(
                  `profile_type.${ProfileTypeStepForm[
                    step
                  ].toLowerCase()}.${value}`
                )}
              </label>
            ) : null
          }
        )}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === ''}
      />
    </>
  )
}

export default ProfileTypeFormSingleChoice
