import { FluidType } from 'enum/fluid.enum'
import { TimeStep } from 'enum/timeStep.enum'
import { mount } from 'enzyme'
import React from 'react'
import { act } from 'react-dom/test-utils'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { graphData } from '../../../tests/__mocks__/chartData.mock'
import { mockInitialChartState } from '../../../tests/__mocks__/store'
import TotalConsumption from './TotalConsumption'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockStore = configureStore([])
const mockChartStore = mockStore({
  ecolyo: {
    chart: {
      ...mockInitialChartState,
      currentDatachart: graphData,
    },
  },
})

describe('TotalConsumption component', () => {
  it('should be rendered correctly', async () => {
    const component = mount(
      <Provider store={mockChartStore}>
        <TotalConsumption fluidType={FluidType.ELECTRICITY} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      component.update()
    })
    expect(component).toMatchSnapshot()
  })
  it('should render euro value', async () => {
    const component = mount(
      <Provider store={mockChartStore}>
        <TotalConsumption fluidType={FluidType.ELECTRICITY} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      component.update()
    })

    expect(component.find('.euro-value').first().text()).toEqual('22,77')
  })
  it('should format multifluid value', async () => {
    const component = mount(
      <Provider store={mockChartStore}>
        <TotalConsumption fluidType={FluidType.MULTIFLUID} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      component.update()
    })

    expect(component.find('.euro-value').first().text()).toEqual('130,84')
  })
  it('should format multifluid value AND compared value', async () => {
    const store = mockStore({
      ecolyo: {
        chart: {
          ...mockInitialChartState,
          currentDatachart: graphData,
          showCompare: true,
          currentTimeStep: TimeStep.DAY,
        },
      },
    })
    const component = mount(
      <Provider store={store}>
        <TotalConsumption fluidType={FluidType.MULTIFLUID} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      component.update()
    })

    expect(component.find('.euro-value').first().text()).toEqual('130,84')
    expect(component.find('.euro-value').at(1).text()).toEqual('110,66')
  })
  it('should display ----- when half an hour electricity data is not activated', async () => {
    const store = mockStore({
      ecolyo: {
        chart: mockInitialChartState,
        currentDatachart: graphData,
      },
    })
    const component = mount(
      <Provider store={store}>
        <TotalConsumption fluidType={FluidType.ELECTRICITY} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      component.update()
    })

    expect(component.find('.euro-value').first().text()).toEqual('-----')
  })
})
