import { UserChallengeState } from 'enum/userChallenge.enum'
import { ChallengeState } from 'models'
import { Reducer } from 'redux'
import {
  ChallengeActionTypes,
  SET_CHALLENGE_CONSUMPTION,
  SET_USER_CHALLENGE_LIST,
  UNLOCK_NEXT_USER_CHALLENGE,
  UPDATE_USER_CHALLENGE_LIST,
} from './challenge.actions'

const initialState: ChallengeState = {
  userChallengeList: [],
  currentChallenge: null,
  currentDataload: [],
}

export const challengeReducer: Reducer<ChallengeState, ChallengeActionTypes> = (
  state = initialState,
  action
) => {
  if (action.payload == undefined) return state

  const updateState = (updates: Partial<ChallengeState>): ChallengeState => ({
    ...state,
    ...updates,
  })
  switch (action.type) {
    case SET_USER_CHALLENGE_LIST: {
      const filteredCurrentChallenge = action.payload.filter(
        challenge =>
          challenge.state === UserChallengeState.ONGOING ||
          challenge.state === UserChallengeState.DUEL
      )
      const currentChallenge = filteredCurrentChallenge[0] || null
      return updateState({
        userChallengeList: action.payload,
        currentChallenge: currentChallenge,
      })
    }

    case UPDATE_USER_CHALLENGE_LIST: {
      const id = action.payload.id
      const currentChallenge =
        action.payload.state === UserChallengeState.ONGOING ||
        action.payload.state === UserChallengeState.DUEL
          ? action.payload
          : null
      const updatedList = [...state.userChallengeList]
      const findIndex = updatedList.findIndex(challenge => challenge.id === id)
      updatedList[findIndex] = action.payload
      return updateState({
        userChallengeList: updatedList,
        currentChallenge: currentChallenge || state.currentChallenge,
      })
    }
    case UNLOCK_NEXT_USER_CHALLENGE: {
      const id = action.payload.id
      const updatedList = [...state.userChallengeList]
      const findIndex = updatedList.findIndex(challenge => challenge.id === id)
      updatedList[findIndex] = action.payload
      if (typeof updatedList[findIndex + 1] !== 'undefined') {
        updatedList[findIndex + 1] = {
          ...updatedList[findIndex + 1],
          state: UserChallengeState.UNLOCKED,
        }
      }
      return updateState({
        userChallengeList: updatedList,
        currentChallenge: null,
      })
    }
    case SET_CHALLENGE_CONSUMPTION: {
      const id = action.payload.userChallenge.id
      const updatedList = [...state.userChallengeList]
      const findIndex = updatedList.findIndex(challenge => challenge.id === id)
      updatedList[findIndex] = action.payload.userChallenge
      return updateState({
        userChallengeList: updatedList,
        currentChallenge:
          state.currentChallenge &&
          state.currentChallenge.id === action.payload.userChallenge.id
            ? action.payload.userChallenge
            : state.currentChallenge,
        currentDataload: action.payload.currentDataload,
      })
    }
    default:
      return state
  }
}
