import { PayloadAction, createSlice } from '@reduxjs/toolkit'
import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { ChartState, Datachart } from 'models'

type SetCurrentDataChart = PayloadAction<Datachart>
type SetCurrentDataChartIndex = PayloadAction<number>
type SetCurrentIndex = PayloadAction<number>
type SetCurrentTimeStep = PayloadAction<TimeStep>
type SetLoading = PayloadAction<boolean>
type SetSelectedDate = PayloadAction<DateTime>
type SetShowCompare = PayloadAction<boolean>
type SetShowOfflineData = PayloadAction<boolean>

export type ChartActionTypes =
  | SetCurrentDataChart
  | SetCurrentDataChartIndex
  | SetCurrentIndex
  | SetCurrentTimeStep
  | SetLoading
  | SetSelectedDate
  | SetShowCompare
  | SetShowOfflineData

const initialState: ChartState = {
  selectedDate: DateTime.local().endOf('minute').setZone('utc', {
    keepLocalTime: true,
  }),
  currentTimeStep: TimeStep.WEEK,
  currentIndex: 0,
  currentDatachart: { actualData: [], comparisonData: null },
  currentDatachartIndex: 0,
  loading: true,
  showCompare: false,
  showOfflineData: false,
}

export const chartSlice = createSlice({
  name: 'chart',
  initialState,
  reducers: {
    setCurrentDataChart: (state, action: SetCurrentDataChart) => {
      state.currentDatachart = action.payload
    },
    setCurrentDataChartIndex: (state, action: SetCurrentDataChartIndex) => {
      state.currentDatachartIndex = action.payload
    },
    setCurrentIndex: (state, action: SetCurrentIndex) => {
      state.currentIndex = action.payload
    },
    setCurrentTimeStep: (state, action: SetCurrentTimeStep) => {
      state.currentTimeStep = action.payload
      if (state.currentTimeStep === TimeStep.YEAR) {
        state.showCompare = false
      }
    },
    setLoading: (state, action: SetLoading) => {
      state.loading = action.payload
    },
    setSelectedDate: (state, action: SetSelectedDate) => {
      state.selectedDate = action.payload
    },
    setShowCompare: (state, action: SetShowCompare) => {
      state.showCompare = action.payload
    },
    setShowOfflineData: (state, action: SetShowOfflineData) => {
      state.showOfflineData = action.payload
    },
  },
})

export const {
  setCurrentDataChart,
  setCurrentDataChartIndex,
  setCurrentIndex,
  setCurrentTimeStep,
  setLoading,
  setSelectedDate,
  setShowCompare,
  setShowOfflineData,
} = chartSlice.actions
