/* eslint-disable camelcase */
import { FluidState, FluidType } from 'enum/fluid.enum'
import { FluidSlugType } from 'enum/fluidSlug.enum'
import { ScreenType } from 'enum/screen.enum'
import { FluidStatus, GlobalState } from 'models'
import { Reducer } from 'redux'
import {
  CHANGE_SCREEN_TYPE,
  GlobalActionTypes,
  SET_FLUID_STATUS,
  SET_PARTNERS_INFO,
  SET_SHOULD_REFRESH_CONSENT,
  SHOW_RELEASE_NOTES,
  TOGGLE_ANALYSIS_NOTIFICATION,
  TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
  TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
  TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
  UPDATE_FLUID_CONNECTION,
  UPDATE_SGE_CONNECT,
  UPDATE_TERMS_VALIDATION,
} from 'store/global/global.actions'

const initialState: GlobalState = {
  screenType: ScreenType.MOBILE,
  releaseNotes: {
    show: false,
    notes: [
      {
        title: '',
        description: '',
      },
    ],
  },
  challengeExplorationNotification: false,
  challengeActionNotification: false,
  challengeDuelNotification: false,
  analysisNotification: false,
  termsStatus: {
    accepted: true,
    versionType: 'init',
  },
  fluidStatus: [
    {
      fluidType: FluidType.ELECTRICITY,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.ELECTRICITY,
          siteLink: '',
          activation: '',
        },
      },
    },
    {
      fluidType: FluidType.WATER,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.WATER,
          siteLink: '',
          activation: '',
        },
      },
    },
    {
      fluidType: FluidType.GAS,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.GAS,
          siteLink: '',
          activation: '',
        },
      },
    },
  ],
  fluidTypes: [],
  partnersInfo: {
    egl_failure: false,
    enedis_failure: false,
    grdf_failure: false,
    notification_activated: false,
  },
  shouldRefreshConsent: false,
  sgeConnect: {
    currentStep: 0,
    firstName: '',
    lastName: '',
    pdl: null,
    address: '',
    zipCode: null,
    city: '',
    dataConsent: false,
    pdlConfirm: false,
    shouldLaunchAccount: false,
  },
}

const getFluidTypesFromStatus = (fluidStatus: FluidStatus[]): FluidType[] => {
  const fluidTypes: FluidType[] = []
  fluidStatus.forEach(fluid => {
    if (
      (fluid.status !== FluidState.KONNECTOR_NOT_FOUND &&
        fluid.status !== FluidState.NOT_CONNECTED &&
        fluid.status !== FluidState.ERROR_LOGIN_FAILED) ||
      // Handle Login Error case for oauth konnectors
      (fluid.status === FluidState.ERROR_LOGIN_FAILED &&
        fluid.fluidType !== FluidType.WATER)
    ) {
      fluidTypes.push(fluid.fluidType)
    }
  })
  return fluidTypes.sort()
}

export const globalReducer: Reducer<GlobalState, GlobalActionTypes> = (
  state = initialState,
  action
) => {
  if (action.payload == undefined) return state

  const updateState = (updates: Partial<GlobalState>): GlobalState => ({
    ...state,
    ...updates,
  })

  switch (action.type) {
    case CHANGE_SCREEN_TYPE:
      return updateState({ screenType: action.payload })

    case TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION:
      return updateState({ challengeExplorationNotification: action.payload })

    case TOGGLE_CHALLENGE_ACTION_NOTIFICATION:
      return updateState({ challengeActionNotification: action.payload })

    case TOGGLE_CHALLENGE_DUEL_NOTIFICATION:
      return updateState({ challengeDuelNotification: action.payload })

    case TOGGLE_ANALYSIS_NOTIFICATION:
      return updateState({ analysisNotification: action.payload })

    case SET_FLUID_STATUS:
      return updateState({
        fluidStatus: action.payload,
        fluidTypes: getFluidTypesFromStatus(action.payload),
      })

    case UPDATE_TERMS_VALIDATION:
      return updateState({ termsStatus: action.payload })

    case SHOW_RELEASE_NOTES:
      return updateState({ releaseNotes: action.payload })

    case SET_PARTNERS_INFO:
      return updateState({ partnersInfo: action.payload })

    case SET_SHOULD_REFRESH_CONSENT:
      return updateState({ shouldRefreshConsent: action.payload })

    case UPDATE_FLUID_CONNECTION:
      const updatedFluidStatus = [...state.fluidStatus]
      const fluidType: FluidType = action.payload.fluidType
      const findIndex = state.fluidStatus.findIndex(
        fluid => fluid.fluidType === fluidType
      )
      updatedFluidStatus[findIndex].connection = action.payload.fluidConnection
      return {
        ...state,
        fluidStatus: updatedFluidStatus,
      }
    case UPDATE_SGE_CONNECT:
      return updateState({ sgeConnect: action.payload })

    default:
      return state
  }
}
