import { ModalState } from 'models'
import { mockCustomPopup } from '../../../tests/__mocks__/customPopup.mock'
import { mockInitialModalState } from '../../../tests/__mocks__/store'
import {
  modalSlice,
  openConnectionModal,
  openFeedbackModal,
  openPartnersModal,
  setCustomPopup,
} from './modal.slice'

describe('modal reducer', () => {
  it('should return the initial state', () => {
    const initialState = modalSlice.reducer(undefined, { type: undefined })
    expect(initialState).toEqual(mockInitialModalState)
  })

  describe('openFeedbackModal', () => {
    it('should handle openFeedbackModal', () => {
      const state = modalSlice.reducer(
        mockInitialModalState,
        openFeedbackModal(true)
      )
      expect(state).toEqual({
        ...mockInitialModalState,
        isFeedbacksOpen: true,
      })
    })
  })

  describe('openPartnersModal', () => {
    const partnersModalAllTrue = {
      egl: true,
      enedis: true,
      grdf: true,
    }
    it('should have all partners to false by default', () => {
      const state = modalSlice.reducer(mockInitialModalState, {
        type: undefined,
      })
      const expectedResult: ModalState = {
        ...mockInitialModalState,
        partnersIssueModal: {
          egl: false,
          enedis: false,
          grdf: false,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle openPartnersModal to set all partners to true', () => {
      const state = modalSlice.reducer(
        mockInitialModalState,
        openPartnersModal({ egl: true, enedis: true, grdf: true })
      )
      const expectedResult: ModalState = {
        ...mockInitialModalState,
        partnersIssueModal: {
          ...partnersModalAllTrue,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle openPartnersModal to set some partners to false', () => {
      const state = modalSlice.reducer(
        {
          ...mockInitialModalState,
          partnersIssueModal: {
            ...partnersModalAllTrue,
          },
        },
        openPartnersModal({ egl: true, enedis: false, grdf: false })
      )
      const expectedResult: ModalState = {
        ...mockInitialModalState,
        partnersIssueModal: {
          egl: true,
          enedis: false,
          grdf: false,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle openConnectionModal', () => {
      const state = modalSlice.reducer(
        mockInitialModalState,
        openConnectionModal(true)
      )
      expect(state).toEqual({
        ...mockInitialModalState,
        isConnectionModalOpen: true,
      })
    })
  })

  describe('customPopup', () => {
    it('should handle setCustomPopup', () => {
      const state = modalSlice.reducer(
        mockInitialModalState,
        setCustomPopup(mockCustomPopup)
      )
      expect(state).toEqual({
        ...mockInitialModalState,
        customPopupModal: mockCustomPopup,
      })
    })
  })
})
