import { Client } from 'cozy-client'
import { Profile } from 'models'
import { Dispatch } from 'react'
import ProfileService from 'services/profile.service'
import { AppStore, defaultAction } from 'store'

export const UPDATE_PROFILE = 'UPDATE_PROFILE'

export interface UpdateProfile {
  type: typeof UPDATE_PROFILE
  payload?: Profile
}

export type ProfileActionTypes = UpdateProfile | typeof defaultAction

function updateProfileSuccess(updatedProfile: Profile): UpdateProfile {
  return {
    type: UPDATE_PROFILE,
    payload: updatedProfile,
  }
}

export function updateProfile(updates: Partial<Profile>): any {
  return async (
    dispatch: Dispatch<UpdateProfile>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const profileService = new ProfileService(client)
    const updatedProfile = await profileService.updateProfile(updates)
    if (updatedProfile) {
      dispatch(updateProfileSuccess(updatedProfile))
    }
  }
}
