import { TimeStep } from 'enum/timeStep.enum'
import {
  CustomQuestionType,
  UserQuestionState,
  UserQuizState,
} from 'enum/userQuiz.enum'
import { DateTime } from 'luxon'
import {
  QuizEntity,
  QuestionEntity,
  CustomQuestionEntity,
  UserQuiz,
} from 'models'

export const questionEntity: QuestionEntity = {
  questionLabel:
    'Quelle longueur faisait l’aqueduc du Gier pour acheminer l’eau sur Lyon à l’époque romaine ?',
  answers: [
    { answerLabel: '86 km', isTrue: true },
    {
      answerLabel: '78 km',
      isTrue: false,
    },
    {
      answerLabel: '56 km',
      isTrue: false,
    },
  ],
  explanation:
    "L’aqueduc du Gier est un des aqueducs antiques de Lyon desservant la ville antique de Lugdunum. Avec ses 86 km il est le plus long des quatre aqueducs ayant alimenté la ville en eau, et celui dont les structures sont le mieux conservées. Il doit son nom au fait qu'il puise aux sources du Gier, affluent du Rhône",
  source: 'string',
}

export const customQuestionEntity: CustomQuestionEntity = {
  questionLabel: 'Custom1',
  type: CustomQuestionType.DATE,
  timeStep: TimeStep.DAY,
  interval: TimeStep.DAY,
  period: {},
  singleFluid: false,
}

export const questionEntities: QuestionEntity[] = [
  {
    questionLabel:
      'Quelle longueur faisait l’aqueduc du Gier pour acheminer l’eau sur Lyon à l’époque romaine ?',
    answers: [
      { answerLabel: '86 km', isTrue: true },
      {
        answerLabel: '78 km',
        isTrue: false,
      },
      {
        answerLabel: '56 km',
        isTrue: false,
      },
    ],
    explanation:
      "L’aqueduc du Gier est un des aqueducs antiques de Lyon desservant la ville antique de Lugdunum. Avec ses 86 km il est le plus long des quatre aqueducs ayant alimenté la ville en eau, et celui dont les structures sont le mieux conservées. Il doit son nom au fait qu'il puise aux sources du Gier, affluent du Rhône",
    source: 'string',
  },
  {
    questionLabel:
      "En 1800 à Lyon, combien de points d'eau y avait-il par habitants ?",
    answers: [
      {
        answerLabel: '1 point d’eau public pour 800 habitants.',
        isTrue: true,
      },
      {
        answerLabel: '1 point d’eau public pour 400 habitants.',
        isTrue: false,
      },
      {
        answerLabel: '1 point d’eau public pour 200 habitants.',
        isTrue: false,
      },
    ],
    explanation: 'string',
    source: 'string',
  },
  {
    questionLabel:
      'Qui officialise la création de la Compagnie Générale des eaux ?',
    answers: [
      { answerLabel: 'François Mitterrand', isTrue: false },
      {
        answerLabel: 'Napoléon Ier',
        isTrue: true,
      },
      {
        answerLabel: 'Napoléon III',
        isTrue: false,
      },
    ],
    explanation: 'string',
    source: 'string',
  },
  {
    questionLabel:
      'Quel ingénieur est à l’origine du projet d’alimentation en eau en 1856 ?',
    answers: [
      { answerLabel: 'string', isTrue: false },
      {
        answerLabel: 'string',
        isTrue: false,
      },
      {
        answerLabel: 'Aristide Dumont',
        isTrue: true,
      },
    ],
    explanation: 'string',
    source: 'string',
  },
]

export const quizEntity: QuizEntity = {
  id: 'QUIZ001',
  questions: questionEntities,
  customQuestion: customQuestionEntity,
  startDate: null,
}

export const allQuizEntities: QuizEntity[] = [
  {
    id: 'QUIZ001',
    questions: questionEntities,
    customQuestion: customQuestionEntity,
    startDate: null,
  },
  {
    id: 'QUIZ002',
    questions: questionEntities,
    customQuestion: customQuestionEntity,
    startDate: null,
  },
]

export const quizDefault: UserQuiz = {
  id: '',
  questions: [],
  customQuestion: {
    questionLabel: '',
    type: CustomQuestionType.DATE,
    timeStep: TimeStep.DAY,
    interval: TimeStep.DAY,
    period: {},
    result: 0,
    singleFluid: false,
  },
  state: UserQuizState.UNLOCKED,
  startDate: null,
  result: 0,
}
export const UserQuizStarted: UserQuiz = {
  id: '',
  questions: [],
  customQuestion: {
    questionLabel: '',
    type: CustomQuestionType.DATE,
    timeStep: TimeStep.DAY,
    interval: TimeStep.DAY,
    period: {},
    result: 0,
    singleFluid: false,
  },
  state: UserQuizState.ONGOING,
  startDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  result: 0,
}
export const UserQuizDone: UserQuiz = {
  id: '',
  questions: [],
  customQuestion: {
    questionLabel: '',
    type: CustomQuestionType.DATE,
    timeStep: TimeStep.DAY,
    interval: TimeStep.DAY,
    period: {},
    result: 0,
    singleFluid: false,
  },
  state: UserQuizState.DONE,
  startDate: null,
  result: 0,
}
export const UserQuizReseted: UserQuiz = {
  id: '',
  questions: [],
  customQuestion: {
    questionLabel: '',
    type: CustomQuestionType.DATE,
    timeStep: TimeStep.DAY,
    interval: TimeStep.DAY,
    period: {},
    result: 0,
    singleFluid: false,
  },
  state: UserQuizState.UNLOCKED,
  startDate: null,
  result: 0,
}

export const userQuiz: UserQuiz = {
  customQuestion: {
    period: {},
    interval: TimeStep.DAY,
    questionLabel: 'Custom1',
    timeStep: TimeStep.DAY,
    type: CustomQuestionType.DATE,
    result: 0,
    singleFluid: false,
  },
  id: 'QUIZ001',
  questions: [
    {
      answers: [
        { answerLabel: '86 km', isTrue: true },
        { answerLabel: '78 km', isTrue: false },
        { answerLabel: '56 km', isTrue: false },
      ],
      explanation:
        "L’aqueduc du Gier est un des aqueducs antiques de Lyon desservant la ville antique de Lugdunum. Avec ses 86 km il est le plus long des quatre aqueducs ayant alimenté la ville en eau, et celui dont les structures sont le mieux conservées. Il doit son nom au fait qu'il puise aux sources du Gier, affluent du Rhône",
      questionLabel:
        'Quelle longueur faisait l’aqueduc du Gier pour acheminer l’eau sur Lyon à l’époque romaine ?',
      result: 0,
      source: 'string',
    },
    {
      answers: [
        {
          answerLabel: '1 point d’eau public pour 800 habitants.',
          isTrue: true,
        },
        {
          answerLabel: '1 point d’eau public pour 400 habitants.',
          isTrue: false,
        },
        {
          answerLabel: '1 point d’eau public pour 200 habitants.',
          isTrue: false,
        },
      ],
      explanation: 'string',
      questionLabel:
        "En 1800 à Lyon, combien de points d'eau y avait-il par habitants ?",
      result: 0,
      source: 'string',
    },
    {
      answers: [
        { answerLabel: 'François Mitterrand', isTrue: false },
        { answerLabel: 'Napoléon Ier', isTrue: true },
        { answerLabel: 'Napoléon III', isTrue: false },
      ],
      explanation: 'string',
      questionLabel:
        'Qui officialise la création de la Compagnie Générale des eaux ?',
      result: 0,
      source: 'string',
    },
    {
      answers: [
        { answerLabel: 'string', isTrue: false },
        { answerLabel: 'string', isTrue: false },
        { answerLabel: 'Aristide Dumont', isTrue: true },
      ],
      explanation: 'string',
      questionLabel:
        'Quel ingénieur est à l’origine du projet d’alimentation en eau en 1856 ?',
      result: 0,
      source: 'string',
    },
  ],
  startDate: null,
  result: 0,
  state: UserQuizState.UNLOCKED,
}

export const userQuizDone: UserQuiz = {
  customQuestion: {
    period: {},
    interval: TimeStep.DAY,
    questionLabel: 'Custom1',
    timeStep: TimeStep.DAY,
    type: CustomQuestionType.DATE,
    result: 0,
    singleFluid: false,
  },
  id: 'QUIZ001',
  questions: [
    {
      answers: [
        { answerLabel: '86 km', isTrue: true },
        { answerLabel: '78 km', isTrue: false },
        { answerLabel: '56 km', isTrue: false },
      ],
      explanation:
        "L’aqueduc du Gier est un des aqueducs antiques de Lyon desservant la ville antique de Lugdunum. Avec ses 86 km il est le plus long des quatre aqueducs ayant alimenté la ville en eau, et celui dont les structures sont le mieux conservées. Il doit son nom au fait qu'il puise aux sources du Gier, affluent du Rhône",
      questionLabel:
        'Quelle longueur faisait l’aqueduc du Gier pour acheminer l’eau sur Lyon à l’époque romaine ?',
      result: UserQuestionState.CORRECT,
      source: 'string',
    },
    {
      answers: [
        {
          answerLabel: '1 point d’eau public pour 800 habitants.',
          isTrue: true,
        },
        {
          answerLabel: '1 point d’eau public pour 400 habitants.',
          isTrue: false,
        },
        {
          answerLabel: '1 point d’eau public pour 200 habitants.',
          isTrue: false,
        },
      ],
      explanation: 'string',
      questionLabel:
        "En 1800 à Lyon, combien de points d'eau y avait-il par habitants ?",
      result: UserQuestionState.CORRECT,
      source: 'string',
    },
    {
      answers: [
        { answerLabel: 'François Mitterrand', isTrue: false },
        { answerLabel: 'Napoléon Ier', isTrue: true },
        { answerLabel: 'Napoléon III', isTrue: false },
      ],
      explanation: 'string',
      questionLabel:
        'Qui officialise la création de la Compagnie Générale des eaux ?',
      result: UserQuestionState.CORRECT,
      source: 'string',
    },
    {
      answers: [
        { answerLabel: 'string', isTrue: false },
        { answerLabel: 'string', isTrue: false },
        { answerLabel: 'Aristide Dumont', isTrue: true },
      ],
      explanation: 'string',
      questionLabel:
        'Quel ingénieur est à l’origine du projet d’alimentation en eau en 1856 ?',
      result: UserQuestionState.UNCORRECT,
      source: 'string',
    },
  ],
  startDate: null,
  result: 3,
  state: UserQuizState.DONE,
}
