/* eslint-disable camelcase */
import { FluidState, FluidType } from 'enum/fluid.enum'
import { FluidSlugType } from 'enum/fluidSlug.enum'
import {
  ConstructionYear,
  Floor,
  HotWaterEquipment,
  HotWaterFluid,
  HousingType,
  IndividualInsulationWork,
  IndividualOrCollective,
  OutsideFacingWalls,
  ThreeChoicesAnswer,
  WarmingType,
} from 'enum/profileType.enum'
import { ScreenType } from 'enum/screen.enum'
import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import {
  AnalysisState,
  ChallengeState,
  ChartState,
  FluidStatus,
  GlobalState,
  ModalState,
  Profile,
  ProfileType,
} from 'models'
import { ProfileEcogesture } from 'models/profileEcogesture.model'
import configureStore from 'redux-mock-store'
import thunkMiddleware from 'redux-thunk'
import { AppActionsTypes, EcolyoState } from 'store'
import mockClient from './client'
import { mockProfileEcogesture } from './profileEcogesture.mock'

export const mockInitialGlobalState: GlobalState = {
  screenType: ScreenType.MOBILE,
  challengeExplorationNotification: false,
  challengeActionNotification: false,
  challengeDuelNotification: false,
  analysisNotification: false,
  termsStatus: {
    accepted: true,
    versionType: 'init',
  },
  partnersInfo: {
    egl_failure: false,
    enedis_failure: false,
    grdf_failure: false,
    notification_activated: false,
  },
  releaseNotes: {
    show: false,
    notes: [{ description: '', title: '' }],
  },
  fluidStatus: [
    {
      fluidType: FluidType.ELECTRICITY,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.ELECTRICITY,
          siteLink: '',
          activation: '',
        },
      },
    },
    {
      fluidType: FluidType.WATER,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.WATER,
          siteLink: '',
          activation: '',
        },
      },
    },
    {
      fluidType: FluidType.GAS,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.GAS,
          siteLink: '',
          activation: '',
        },
      },
    },
  ],
  fluidTypes: [],
  shouldRefreshConsent: false,
  sgeConnect: {
    address: '',
    city: '',
    currentStep: 0,
    dataConsent: false,
    firstName: '',
    lastName: '',
    pdl: null,
    pdlConfirm: false,
    zipCode: null,
    shouldLaunchAccount: false,
  },
}
export const mockExpiredElec: FluidStatus = {
  fluidType: FluidType.ELECTRICITY,
  status: FluidState.KONNECTOR_NOT_FOUND,
  maintenance: true,
  firstDataDate: null,
  lastDataDate: null,
  connection: {
    shouldLaunchKonnector: false,
    isUpdating: false,
    konnector: null,
    account: {
      _id: '1',
      account_type: 'test',
      data: {
        consentId: 1,
        expirationDate: '1999-08-08',
      },
    },
    trigger: null,
    triggerState: {
      trigger_id: '0',
      status: '',
      last_executed_job_id: '',
      last_execution: '',
      last_manual_execution: '',
      last_manual_job_id: '',
      last_error: 'USER_ACTION_NEEDED.OAUTH_OUTDATED',
    },
    konnectorConfig: {
      name: '',
      oauth: false,
      slug: FluidSlugType.ELECTRICITY,
      siteLink: '',
      activation: '',
    },
  },
}

export const mockExpiredGas: FluidStatus = {
  fluidType: FluidType.GAS,
  status: FluidState.ERROR_LOGIN_FAILED,
  maintenance: false,
  firstDataDate: null,
  lastDataDate: null,
  connection: {
    shouldLaunchKonnector: false,
    isUpdating: false,
    konnector: null,
    account: null,
    trigger: null,
    triggerState: {
      trigger_id: '0',
      status: '',
      last_executed_job_id: '',
      last_execution: '',
      last_manual_execution: '',
      last_manual_job_id: '',
      last_error: 'USER_ACTION_NEEDED.OAUTH_OUTDATED',
    },
    konnectorConfig: {
      name: '',
      oauth: false,
      slug: FluidSlugType.GAS,
      siteLink: '',
      activation: '',
    },
  },
}
export const mockMaintenanceGas: FluidStatus = {
  ...mockExpiredGas,
  maintenance: true,
}

export const mockInitialProfileState: Profile = {
  id: '',
  ecogestureHash: '',
  challengeHash: '',
  duelHash: '',
  quizHash: '',
  explorationHash: '',
  isFirstConnection: false,
  partnersIssueSeenDate: {
    enedis: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
    egl: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
    grdf: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
  },
  lastConnectionDate: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
  haveSeenLastAnalysis: true,
  sendConsumptionAlert: false,
  waterDailyConsumptionLimit: 0,
  sendAnalysisNotification: true,
  isProfileEcogestureCompleted: false,
  mailToken: '',
  monthlyAnalysisDate: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
  isProfileTypeCompleted: false,
  onboarding: {
    isWelcomeSeen: true,
  },
  haveSeenEcogestureModal: false,
  activateHalfHourDate: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
  customPopupDate: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
}

export const mockInitialProfileTypeState: ProfileType = {
  housingType: HousingType.INDIVIDUAL_HOUSE,
  constructionYear: ConstructionYear.BETWEEN_1975_AND_1989,
  area: '100',
  occupantsNumber: 4,
  outsideFacingWalls: OutsideFacingWalls.TWO,
  floor: Floor.NOT_APPLICABLE,
  heating: IndividualOrCollective.INDIVIDUAL,
  coldWater: IndividualOrCollective.INDIVIDUAL,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  individualInsulationWork: [
    IndividualInsulationWork.WINDOW_REPLACEMENT,
    IndividualInsulationWork.WALL_INSULATION,
  ],
  hasInstalledVentilation: ThreeChoicesAnswer.UNKNOWN,
  hasReplacedHeater: ThreeChoicesAnswer.UNKNOWN,
  hotWaterEquipment: HotWaterEquipment.SOLAR,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWaterFluid: HotWaterFluid.ELECTRICITY,
  cookingFluid: FluidType.ELECTRICITY,
  updateDate: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
  equipments: [],
}

export const mockInitialChartState: ChartState = {
  selectedDate: DateTime.local().endOf('minute').setZone('utc', {
    keepLocalTime: true,
  }),
  currentTimeStep: TimeStep.WEEK,
  currentIndex: 0,
  currentDatachart: { actualData: [], comparisonData: null },
  currentDatachartIndex: 0,
  loading: true,
  showCompare: false,
  showOfflineData: false,
}

export const mockInitialModalState: ModalState = {
  customPopupModal: {
    popupEnabled: false,
    title: '',
    description: '',
    endDate: '',
  },
  isConnectionModalOpen: false,
  isFeedbacksOpen: false,
  partnersIssueModal: {
    enedis: false,
    egl: false,
    grdf: false,
  },
}

export const mockInitialChallengeState: ChallengeState = {
  userChallengeList: [],
  currentChallenge: null,
  currentDataload: [],
}

export const mockInitialAnalysisState: AnalysisState = {
  period: 'month',
}

export const mockInitialEcolyoState: EcolyoState = {
  analysis: mockInitialAnalysisState,
  challenge: mockInitialChallengeState,
  chart: mockInitialChartState,
  global: mockInitialGlobalState,
  modal: mockInitialModalState,
  profile: mockInitialProfileState,
  profileType: mockInitialProfileTypeState,
  profileEcogesture: mockProfileEcogesture,
}

const middlewares = [thunkMiddleware.withExtraArgument({ mockClient })]
const mockStore = configureStore<
  {
    ecolyo: {
      analysis: AnalysisState
      challenge: ChallengeState
      chart: ChartState
      global: GlobalState
      modal: ModalState
      profile: Profile
      profileEcogesture: ProfileEcogesture
      profileType: ProfileType
    }
    cozy: unknown
  },
  AppActionsTypes
>(middlewares)
const mockedStore = mockStore({
  ecolyo: mockInitialEcolyoState,
  cozy: {},
})

/**
 * Create a mocked Ecolyo store with the default mockInitialEcolyoState
 */
export const createMockEcolyoStore = (
  initialState: EcolyoState = mockInitialEcolyoState
) => {
  return mockStore({
    ecolyo: initialState,
    cozy: {},
  })
}

export default mockedStore
